@@ -1,7 +1,7 @@
 package Huawei::Healthchecker;
 
 #版本信息
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 use strict;
 use warnings;
@@ -119,7 +119,7 @@ sub health_check {
     my $result = [ \@hardware_ret, \@status_ret, $score, $comment ];
 
     #返回健康检查结果
-    return ( $ret, $result );
+    return ( $rev, $result );
 }
 
 #-------------------------------------------------------------------------
